@@ -17,6 +17,7 @@
 '''
 from __future__ import absolute_import
 
+import inspect
 import os
 import sys
 import re
@@ -28,7 +29,7 @@ import six
 
 from testbase.assertion import AssertionRewriter
 from testbase.util import Singleton, ThreadGroupLocal, ThreadGroupScope, smart_text, get_last_frame_stack
-from testbase.testresult import EnumLogLevel, TestResultCollection
+from testbase.testresult import EnumLogLevel, TestResultCollection, TestResultType
 from testbase.conf import settings
 from testbase.retry import Retry
 
@@ -314,6 +315,19 @@ class TestCase(object):
             self.__resmgr_session = self.__resmgr.create_session(self)
         return self.__resmgr_session
 
+    def get_test_extra_properties(self):
+        var_dicts = {}
+        for k, v in inspect.getmembers(self):
+            if k in self.ATTRIB_OVERWRITE_WHITELIST:
+                continue
+            if not (isinstance(v, bool) or isinstance(v, int) or isinstance(v, float) or isinstance(v, (six.string_types, six.binary_type))):
+                continue
+            if k.islower() and not k.startswith('_') and not k.startswith('test_'):
+                if isinstance(v, (six.string_types, six.binary_type)):
+                    v = smart_text(v)
+                var_dicts[k] = v
+        return var_dicts
+
     def init_test(self, testresult):
         '''初始化测试用例。慎用此函数，尽量将初始化放到preTest里。
 
@@ -342,6 +356,7 @@ class TestCase(object):
         '''
         if self.__resmgr_session:
             self.test_resources.destroy()
+            self.__resmgr_session = None
 
     def start_step(self, stepinfo):
         '''开始执行一个测试步骤
@@ -389,6 +404,8 @@ class TestCase(object):
                                                     expect.__class__, expect,
                                                     actual.__class__, actual)
         self.__testresult.log_record(EnumLogLevel.ASSERT, msg)
+        if not settings.get("QTAF_ASSERT_CONTINUE", True):
+            raise RuntimeError("testcase assert failed:%s" % message)
 
     def _log_assert_failed(self, message, back_count=2):
         """记录断言失败的信息
@@ -699,9 +716,25 @@ class TestCaseRunner(ITestCaseRunner):
                         if it in ['init_test', 'initTest']:
                             getattr(self._testcase, it)(self._testresult)
                         else:
-                            getattr(self._testcase, it)()
+                            task_result = getattr(self._testcase, it)()
+                            if task_result and isinstance(task_result, six.string_types):
+                                valid_task_result = False
+                                for name in TestResultType.__dict__:
+                                    value = TestResultType.__dict__[name]
+                                    if task_result == value:
+                                        valid_task_result = True
+                                        break
+                                if not valid_task_result:
+                                    self._testresult.warning('指定的自定义状态不支持，用例将继续执行')
+                                else:
+                                    self._testresult.customize_result(task_result)
+                                    while self._subtasks[0] not in ['post_test', 'postTest']:
+                                        self._subtasks.popleft()
                     except:
                         self._testresult.exception('%s执行失败' % it)
+                        if settings.get("QTAF_FAILED_SKIP_RUNTEST", False) and it in ['pre_test', 'preTest']:
+                            while self._subtasks[0] not in ['post_test', 'postTest']:
+                                self._subtasks.popleft()
                 else:
                     it()
 
